@@ -5,7 +5,7 @@
     #. 语言检测, 支持批量检测
     #. 文本翻译, 支持批量, 支持 html 模式翻译
 """
-from typing import List, Union, overload
+from typing import List, Union, overload, Dict
 
 import requests
 
@@ -22,8 +22,12 @@ class Translate:
     :param user_agent: str: (可选) 用户代理, 这个参数很重要, 不设置或错误设置非常容易触发 **429 Too Many Requests** 错误,
         默认: ``GoogleTranslate/6.18.0.06.376053713 (Linux; U; Android 11; GM1900)``, 所以用户可以不用提供.
         这个默认 ``User-Agent`` 很稳定, 暂时未发现 ``429 错误``, 如果出现 ``429``, 建议 **模仿默认 进行构造**,
-        或者进行\ `反馈 <https://github.com/foyoux/pygtrans/issues/new>`_
+        或者进行 `反馈 <https://github.com/foyoux/pygtrans/issues/new>`_
     :param domain: str: (可选) 域名 ``google.com`` 及其可用平行域名 (如: ``google.cn``), 默认: ``google.cn``
+    :param proxies: (可选) eg: proxies = {
+            'http': 'http://localhost:10809',
+            'https': 'http://localhost:10809'
+        }
 
 
     基本用法:
@@ -58,7 +62,8 @@ class Translate:
             source: str = 'auto',
             _format='html',
             user_agent: str = 'GoogleTranslate/6.18.0.06.376053713 (Linux; U; Android 11; GM1900)',
-            domain: str = 'cn'
+            domain: str = 'cn',
+            proxies: Dict = None
     ):
         self.target = target
         self.source = source
@@ -72,6 +77,9 @@ class Translate:
         self.DETECT_URL: str = f'{self.BASE_URL}/translate_a/single'
         self.TRANSLATE_URL: str = f'{self.BASE_URL}/translate_a/t'
 
+        if proxies is not None:
+            self.session.proxies = proxies
+
     # @lru_cache
     # def languages(self, target: str = None) -> List[LanguageResponse]:
     #     """获取语言列表
