@@ -7,17 +7,16 @@ from .Null import Null
 from .Translate import Translate
 from .TranslateResponse import TranslateResponse
 
-__apikey__ = '<your-apikey>'
+__apikey__ = '<your-api-key>'
 
 __title__ = 'pygtrans'
 __description__ = 'Google Translate, support APIKEY'
 __url__ = 'https://github.com/foyoux/pygtrans'
-__version__ = '1.0.2'
+__version__ = '1.0.3'
 __author__ = 'foyou'
 __author_email__ = 'yimi.0822@qq.com'
-__license__ = 'MIT'
+__license__ = 'GPL-3.0'
 __copyright__ = f'Copyright 2021 {__author__}'
 __ide__ = 'PyCharm - https://www.jetbrains.com/pycharm/'
 
-
 __all__ = ['Translate', 'ApiKeyTranslate', 'Null', 'LanguageResponse', 'DetectResponse', 'TranslateResponse']
